#ifndef OPENSYNCMERGER_H_
#define OPENSYNCMERGER_H_

OPENSYNC_BEGIN_DECLS

#include "merger/opensync_capabilities.h"
#include "merger/opensync_capability.h"
#include "merger/opensync_xmlformat.h"
#include "merger/opensync_xmlfield.h"
#include "merger/opensync_xmlfieldlist.h"
#include "merger/opensync_merger.h"

OPENSYNC_END_DECLS

#endif /*OPENSYNCMERGER_H_*/
