#ifndef HAVE_ENGINE_H
#define HAVE_ENGINE_H

OPENSYNC_BEGIN_DECLS

#include "engine/opensync_engine.h"
#include "engine/opensync_mapping_engine.h"
#include "engine/opensync_obj_engine.h"
#include "engine/opensync_status.h"

OPENSYNC_END_DECLS

#endif
